<?php

function register_portfolio_post_type(){
	
	register_post_type('portfolio', array(
		'labels' => array(
			'name' => 'Portfolio',
			'singular_name' => 'Portfolio',
			'add_new' => 'Add New',
			'add_new_item' => 'Add New Portfolio Item',
			'edit_item' => 'Edit Portfolio Item',
			'new_item' => 'New Portfolio Item',
			'view_item' => 'View Portfolio Item',
			'search_items' => 'Search Portfolio Items',
			'not_found' =>  'No portfolio item found',
			'not_found_in_trash' => 'No portfolio items found in Trash', 
			'parent_item_colon' => '',
			'menu_name' => 'Portfolio',
		),
		'singular_label' => 'portfolio',
		'public' => true,
		'publicly_queryable' => true,
		'exclude_from_search' => false,
		'show_ui' => true,
		'show_in_menu' => true,
		'capability_type' => 'page',
		'hierarchical' => false,
		'supports' => array('title', 'editor', 'thumbnail', 'page-attributes', 'comments'),
		'has_archive' => false,
		'rewrite' => array( 'slug' => 'portfolio', 'with_front' => true, 'pages' => true, 'feeds'=>false ),
		'query_var' => false,
		'can_export' => true,
		'show_in_nav_menus' => true,
	));

	//register taxonomy for portfolio
	register_taxonomy('portfolio_category','portfolio',array(
		'hierarchical' => true,
		'labels' => array(
			'name' =>  'Portfolio Categories',
			'singular_name' =>  'Portfolio Category',
			'search_items' =>   'Search Portfolio Categories',
			'popular_items' =>  'Popular Portfolio Categories',
			'all_items' =>  'All Portfolio Categories',
			'parent_item' => null,
			'parent_item_colon' => null,
			'edit_item' =>  'Edit Portfolio Category', 
			'update_item' =>  'Update Portfolio Category',
			'add_new_item' =>  'Add New Portfolio Category',
			'new_item_name' =>  'New Portfolio Category Name',
			'separate_items_with_commas' =>  'Separate Portfolio Category with commas',
			'add_or_remove_items' =>  'Add or remove Portfolio Category',
			'choose_from_most_used' =>  'Choose from the most used Portfolio Category',
			'menu_name' =>  'Categories',
		),
		'public' => true,
		'show_in_nav_menus' => false,
		'show_ui' => true,
		'show_tagcloud' => false,
		'query_var' => false,
		'rewrite' => false,
		
	));	
}
add_action('init','register_portfolio_post_type',0);

function portfolio_context_fixer() {
	if ( get_query_var( 'post_type' ) == 'portfolio' ) {
		global $wp_query;
		$wp_query->is_home = false;
	}
	if ( get_query_var( 'taxonomy' ) == 'portfolio_category' ) {
		global $wp_query;
		$wp_query->is_404 = true;
		$wp_query->is_tax = false;
		$wp_query->is_archive = false;
	}
}
add_action( 'template_redirect', 'portfolio_context_fixer' );


function edit_portfolio_columns($gallery_columns) {
	$columns = array(
		"cb" => "<input type=\"checkbox\" />",
		"title" => 'Name',
		"portfolio_categories" => 'Categories',
		"date" => 'Date',
		"thumbnail" => 'Thumbnail',
		"menu_order" => 'Order'
	);

	return $columns;
}
add_filter('manage_edit-portfolio_columns', 'edit_portfolio_columns');

function manage_portfolio_columns($column) {
	global $post;
	
	if ($post->post_type == "portfolio") {
		switch($column){
			case "portfolio_categories":
				$terms = get_the_terms($post->ID, 'portfolio_category');
				
				if (! empty($terms)) {
					foreach($terms as $t)
						$output[] = "<a href='edit.php?post_type=portfolio&portfolio_category=$t->slug'> " . esc_html(sanitize_term_field('name', $t->name, $t->term_id, 'portfolio_category', 'display')) . "</a>";
					$output = implode(', ', $output);
				} else {
					$t = get_taxonomy('portfolio_category');
					$output = "No $t->label";
				}
				
				echo $output;
				break;
			
			case 'thumbnail':
				the_post_thumbnail('portfolio_one_fourth');
				break;			
			case 'menu_order':
				echo $post->menu_order;
				break;
		}
	}
}
add_action('manage_posts_custom_column', 'manage_portfolio_columns', 10, 2);


function register_gallery_post_type(){
	
	register_post_type('gallery', array(
		'labels' => array(
			'name' => 'Gallery Items',
			'singular_name' => 'Gallery Item',
			'add_new' => 'Add New',
			'add_new_item' => 'Add New Gallery Item',
			'edit_item' => 'Edit Gallery Item',
			'new_item' => 'New Gallery Item',
			'view_item' => 'View Gallery Item',
			'search_items' => 'Search Gallery Items',
			'not_found' =>  'No gallery item found',
			'not_found_in_trash' => 'No gallery items found in Trash', 
			'parent_item_colon' => '',
			'menu_name' => 'Gallery',
		),
		'singular_label' => 'gallery',
		'public' => true,
		'publicly_queryable' => true,
		'exclude_from_search' => false,
		'show_ui' => true,
		'show_in_menu' => true,
		'capability_type' => 'post',
		'hierarchical' => false,
		'supports' => array('title', 'thumbnail', 'page-attributes'),
		'has_archive' => false,
		'rewrite' => array( 'slug' => 'gallery', 'with_front' => true, 'pages' => true, 'feeds'=>false ),
		'query_var' => false,
		'can_export' => true,
		'show_in_nav_menus' => true,
	));

	//register taxonomy for gallery
	register_taxonomy('gallery_category','gallery',array(
		'hierarchical' => true,
		'labels' => array(
			'name' =>  'Galleries',
			'singular_name' =>  'Gallery',
			'search_items' =>   'Search Galleries',
			'popular_items' =>  'Popular Galleries',
			'all_items' =>  'All Galleries',
			'parent_item' => null,
			'parent_item_colon' => null,
			'edit_item' =>  'Edit Gallery', 
			'update_item' =>  'Update Gallery',
			'add_new_item' =>  'Add New Gallery',
			'new_item_name' =>  'New Gallery Name',
			'separate_items_with_commas' =>  'Separate Gallery with commas',
			'add_or_remove_items' =>  'Add or remove Gallery',
			'choose_from_most_used' =>  'Choose from the most used Gallery',
			'menu_name' =>  'Galleries',
		),
		'public' => true,
		'show_in_nav_menus' => false,
		'show_ui' => true,
		'show_tagcloud' => false,
		'query_var' => false,
		'rewrite' => false,
		
	));	
}
add_action('init','register_gallery_post_type',0);

function gallery_context_fixer() {
	if ( get_query_var( 'post_type' ) == 'gallery' ) {
		global $wp_query;
		$wp_query->is_home = false;
	}
	if ( get_query_var( 'taxonomy' ) == 'gallery_category' ) {
		global $wp_query;
		$wp_query->is_404 = true;
		$wp_query->is_tax = false;
		$wp_query->is_archive = false;
	}
}
add_action( 'template_redirect', 'gallery_context_fixer' );

function edit_gallery_columns($gallery_columns) {
	$columns = array(
		"cb" => "<input type=\"checkbox\" />",
		"title" => 'Name',
		"gallery_categories" => 'Categories',
		"date" => 'Date',
		"thumbnail" => 'Thumbnail',
		"menu_order" => 'Order'
	);

	return $columns;
}
add_filter('manage_edit-gallery_columns', 'edit_gallery_columns');

function manage_gallery_columns($column) {
	global $post;
	
	if ($post->post_type == "gallery") {
		switch($column){
			case "gallery_categories":
				$terms = get_the_terms($post->ID, 'gallery_category');
				
				if (! empty($terms)) {
					foreach($terms as $t)
						$output[] = "<a href='edit.php?post_type=gallery&gallery_category=$t->slug'> " . esc_html(sanitize_term_field('name', $t->name, $t->term_id, 'gallery_category', 'display')) . "</a>";
					$output = implode(', ', $output);
				} else {
					$t = get_taxonomy('gallery_category');
					$output = "No $t->label";
				}
				
				echo $output;
				break;
			
			case 'thumbnail':
				the_post_thumbnail('portfolio_one_fourth');
				break;
			case 'menu_order':
				echo $post->menu_order;
				break;
		}
	}
}
add_action('manage_posts_custom_column', 'manage_gallery_columns', 10, 2);

$portfolio_options = array(
	
	array(
		"name" => "Type",
		"desc" => "Choose the type of media",
		"id" => THEME_SLUG."_portfolio_type",
		"std" => "image",
		"type" => "select",
		"size" => "normal",
		"data" => array(
			"image" => "Image",
			"video" => "Video",
			"audio" => "Audio",
			"iframe" => "Iframe",
			"gallery" => "Gallery",
			"link" => "Link",
		)
	),

	array(
		"name" => "Link URL",
		"desc" => "Samples:<br /><br />Image:   http://www.yourdomain.com/wp-content/uploads/project1.jpg<br />YouTube:   http://www.youtube.com/watch?v=VKS08be78os<br />
Vimeo:   http://vimeo.com/8245346<br />Flash:   http://www.yourdomain.com/wp-content/uploads/design.swf?width=792&height=294<br />Audio:   http://www.yourdomain.com/wp-content/uploads/audio.mp3<br />iFrame:   http://www.apple.com?iframe=true&width=850&height=500",
		"id" => THEME_SLUG."_portfolio_url",
		"std" => "",
		"type" => "text",
		"size" => "large"
	), 
	
	array(
		"name" => "Open URL in Lightbox",
		"desc" => "",
		"id" => THEME_SLUG."_portfolio_lightbox",
		"std" => "true",
		"type" => "toggle"		
	),
	
	array(
		"name" => "Gallery",
		"desc" => "If you have chosen the type as \"Gallery\", please choose a gallery from the dropdown",
		"id" => THEME_SLUG."_gallery",
		"std" => "",
		"type" => "gallery_category",
	),
	
);


$info = array(
    "id" => "portfolio",
    "title" => "Portfolio Options",
    "post_type" => "portfolio",
	"context" => "normal",
	"priority" => "high"	
);

$portfolio_option_settings = new MetaboxGenerator($info, $portfolio_options);

?>