<?php

$is_mobile = false;

$mobile_redirect = get_option(THEME_SLUG."_mobile_home");

if(function_exists('theme_check_and_act_mobile') && $mobile_redirect){
	$is_mobile = theme_check_and_act_mobile(get_permalink($mobile_redirect));
}


/***** Add Menus *****/

if (function_exists('add_theme_support')) {
    add_theme_support('nav-menus');
	add_theme_support('menus');
}


/***** Register Menu *****/

register_nav_menu('Primary Navigation', 'Main Navigation');


/***** Activate Post Thumbnails *****/

if ( function_exists( 'add_theme_support' ) ){
	add_theme_support('post-thumbnails', array('post', 'slideshow', 'portfolio'));
}


/***** Custom Thumbnail Sizes *****/

add_image_size('blog_thumb_image', 572, 260, true);
add_image_size('image_full_width', 960, get_option(THEME_SLUG."_homepage_slider_height"), true);

add_image_size('portfolio_full', 600, 260, true);
add_image_size('portfolio_one_half', 458, 200, true);
add_image_size('portfolio_one_third', 292, 160, true);
add_image_size('portfolio_one_fourth', 209, 120, true);
add_image_size('portfolio_thumb', 100, 75, true);


/***** Scripts *****/

function theme_scripts(){
	global $is_mobile;
	
	wp_enqueue_script("jquery");
	if(!$is_mobile){		
		wp_enqueue_script('theme', THEME_JS.'/theme.js', array('jquery'));
		wp_localize_script('theme', 'ThemeAjax', array('ajaxurl' => admin_url( 'admin-ajax.php')));		
		wp_enqueue_script('theme-superfish1', THEME_JS.'/hoverIntent.js', array('jquery'));
		wp_enqueue_script('theme-superfish2', THEME_JS.'/superfish.js', array('jquery'));
		wp_enqueue_script('theme-carousel', THEME_JS.'/jquery.tinycarousel.min.js', array('jquery'));
		wp_enqueue_script('theme-nivo', THEME_JS.'/jquery.nivo.slider.pack.js', array('jquery'));
		wp_enqueue_script('theme-anythingslider', THEME_JS.'/jquery.anythingslider.min.js', array('jquery'));		
		wp_enqueue_script('theme-swfobject', THEME_JS.'/swfobject.js');	
		wp_enqueue_script('theme-jqui', THEME_JS.'/jquery-ui-1.7.3.custom.min.js', array('jquery'));
		wp_enqueue_script('theme-prettyPhoto', THEME_JS.'/jquery.prettyPhoto.js', array('jquery'));	
		
	}
	wp_enqueue_script('theme-gmaps', 'http://maps.googleapis.com/maps/api/js?sensor=false', array(), false, true);	
}
add_action('wp_enqueue_scripts', 'theme_scripts');


/***** CSS *****/

function theme_css(){
	global $is_mobile;
	
	wp_enqueue_style("theme", THEME_HOME.'/style.css');

	$theme = ($_COOKIE['theme']) ? $_COOKIE['theme'] : get_option(THEME_SLUG."_color_theme");
	if($_GET['theme']) {
		if(array_key_exists($_GET['theme'], $GLOBALS['color_themes'])) {
			$theme = $_GET['theme'];
			setcookie('theme', $theme, 0, '/');
		}
	}
	wp_enqueue_style("theme-skin", THEME_CSS.'/themes/'.$theme.'.css');
	
	if($is_mobile){
		wp_enqueue_style("theme-mobile", THEME_CSS.'/mobile.css');
	}
	
}
add_action('wp_print_styles', 'theme_css');


/***** Header *****/

function theme_head_meta(){
	global $is_mobile;
	
	echo '<meta http-equiv="Content-Type" content="'.get_bloginfo('html_type').'; charset='.get_bloginfo('charset').'" />';	
	
	if(!$is_mobile){
	
		if(is_singular()) { wp_enqueue_script('comment-reply');	}
		echo '<meta name="template_url" content="'.get_bloginfo('template_url').'" />';
		
		echo '<title>';
		wp_title('-', true, 'right');
		bloginfo('name');
		echo '</title>';	
		
		echo '<link rel="pingback" href="'.get_bloginfo('pingback_url').'" />';
		
		$favicon_img = get_option(THEME_SLUG."_favicon");
		if($favicon_img) { echo '<link rel="shortcut icon" href="'.$favicon_img.'">'; }
		
	}else{	
		echo '<meta name="viewport" content="width=device-width; initial-scale=1.0; maximum-scale=1.0; user-scalable=false;" />';
		echo '<title>'.get_bloginfo('name').'</title>';			
	}
		
	$fb_appid = get_option(THEME_SLUG."_fb_appid");
	if($fb_appid){ echo '<meta property="fb:app_id" content="'.$fb_appid.'" />'; }
	
}

function theme_header_top(){
	global $is_mobile;
	
	echo '<div id="header-top">';
	echo '<div class="top-toolbar">';
	if(!$is_mobile){
		echo '<div class="top-menu"><ul>';
		dynamic_sidebar("Top Left Navigation");
		echo '</ul></div>';
	}
	echo '<div class="top-toolbar-right">';
	dynamic_sidebar("Top Right Toolbar");
	echo '</div><div class="clear"></div>';
	echo '</div></div>';	
}

function theme_header(){
	global $is_mobile;

	$logo_img = get_option(THEME_SLUG."_site_logo");
	echo '<div class="header-wrapper">';
	echo '<div class="logo"><a href="'.home_url().'"><img src="'.$logo_img.'" alt="'.get_bloginfo('name').'" /></a></div>';
	
	if(!$is_mobile){
		if(get_option(THEME_SLUG."_mainmenu_toggle") == 'true'){
			$depth = "0";
			if(get_option(THEME_SLUG."_mainmenu_dropdown") != "true"){
				$depth = "1";
			}
			
			echo '<div id="main-menu-nav">';
			if(function_exists('wp_nav_menu')){
				echo '<ul id="main-menu">';
				wp_nav_menu(array('container' =>false, 'theme_location' => 'Primary Navigation', 'sort_column' => 'menu_order', 'menu_class' => '', 'echo' => true, 'before' => '', 'after' => '', 'link_before' => '', 'link_after' => '', 'depth' => $depth, 'walker' => new description_walker()));
				echo '</ul>';
			}
			echo '</div>';
		} 	
	}
	echo '</div><div class="clear"></div>';
}

/***** Head *****/

function theme_head($breadcrumbs="true", $title="true"){
	global $is_mobile, $post;

	if(!$is_mobile){		
		
		echo '<div id="head">';
		
		if(get_post_meta($post->ID, THEME_SLUG.'_page_title', true) != "true"){
		
			$bc = get_option(THEME_SLUG."_breadcrumbs");
			
			if((is_front_page() || is_home()) || !(is_front_page())){	
			
				if($bc == "true" && $breadcrumbs == "true") {
					breadcrumbs_plus();
				}
				
				if($title == "true"){
					echo '<h1>';	
					if (is_404()) { echo get_option(THEME_SLUG."_404_title"); }
					elseif (is_search()) { echo "Search Results for '".stripslashes( strip_tags( get_search_query() ) )."'"; }
					else if(have_posts()) : while(have_posts()) : the_post();  the_title();  endwhile; endif;	
					echo '</h1>';
					
					if(get_option(THEME_SLUG."_searchbar")) {
						$page_template = basename(get_page_template());
						if($page_template == 'page.php' || $page_template == 'template-feature-left.php' || $page_template == 'template-feature-right.php' || $page_template == 'template-home.php'){ echo theme_search_bar();}
					}
					echo '<div class="horizontal-separator"></div>';
				}			
				
			}
		}	
		echo '</div>';					
	}
}

function theme_search_bar(){
	$output = '<form method="get" id="search-form" action="'.get_bloginfo('siteurl').'" >';
	$output .= '<div><input type="text" name="s" value="Search" id="s" onfocus=\'this.value=(this.value=="Search") ? "" : this.value;\' onblur=\'this.value=(this.value=="") ? "Search" : this.value;\' /><input type="submit" id="searchsubmit" value="Search" />';
	$output .= '</div></form>';
	return $output;
}

function theme_sidebar($submenu=true, $widgets=true, $type="content", $align=""){
	
	if($align){
		$align = "-".$align;
	}
	
	echo '<div id="'.$type.'-sidebar'.$align.'">';
	if(get_option(THEME_SLUG."_searchbar")) {
		$page_template = basename(get_page_template());
		if(!($page_template == 'page.php' || $page_template == 'template-feature-left.php' || $page_template == 'template-feature-right.php' || $page_template == 'template-home.php')){ 
			echo theme_search_bar();
			echo '<div class="divider"></div>';
		}
	}
	
	if(get_option(THEME_SLUG."_submenu_toggle") == "true" && $submenu) {
		if(function_exists('theme_submenu')){
			theme_submenu();
		}
	}
	
	if($widgets){	
		if($type == "content"){
			if( !function_exists('dynamic_sidebar') || !dynamic_sidebar("Content Sidebar") ) {}	
			generated_dynamic_sidebar();
		}
		if($type == "blog"){
			if( !function_exists('dynamic_sidebar') || !dynamic_sidebar("Blog Sidebar") ) {}	
		}	
	}
	echo '</div>';
}


/***** Footer *****/

function theme_footer_widgets() {
	global $is_mobile;
	if(!$is_mobile){
		echo '<div class="footer-wrapper">';
		$footer_columns = get_option(THEME_SLUG."_footer_columns");
		$footer_separator = (get_option(THEME_SLUG."_footer_separator") == "true")?' separator':'';
		
		switch($footer_columns){
			case 'one':
				get_footer_sidebar(1, 'full');
				break;
			case 'one-half':
				get_footer_sidebar(1, 'one-half'.$footer_separator);
				get_footer_sidebar(2, 'one-half last');
				break;
			case 'one-third':
				get_footer_sidebar(1, 'one-third'.$footer_separator);
				get_footer_sidebar(2, 'one-third'.$footer_separator);
				get_footer_sidebar(3, 'one-third last');
				break;
			case 'one-fourth':
				get_footer_sidebar(1, 'one-fourth'.$footer_separator);
				get_footer_sidebar(2, 'one-fourth'.$footer_separator);
				get_footer_sidebar(3, 'one-fourth'.$footer_separator);
				get_footer_sidebar(4, 'one-fourth last');
				break;
			case 'one-third-two-third':
				get_footer_sidebar(1, 'one-third'.$footer_separator);
				get_footer_sidebar(2, 'two-third last');
				break;
			case 'two-third-one-third':
				get_footer_sidebar(1, 'two-third'.$footer_separator);
				get_footer_sidebar(2, 'one-third last');
				break;		
			case 'one-fourth-three-fourth':
				get_footer_sidebar(1, 'one-fourth'.$footer_separator);
				get_footer_sidebar(2, 'three-fourth last');
				break;
			case 'three-fourth-one-fourth':
				get_footer_sidebar(1, 'three-fourth'.$footer_separator);
				get_footer_sidebar(2, 'one-fourth last');
				break;		
		}

		echo '<div class="clear"></div></div>';
	}
}

function get_footer_sidebar($i, $class){
	global $footer_column_sidebars;
	echo '<div class="'.$class.'">';
	dynamic_sidebar($footer_column_sidebars[$i-1]);
	echo '</div>';
}

function theme_footer_bottom(){
	global $is_mobile;
	if(!$is_mobile){
		echo '<div id="footer-bottom">';
		echo '<div class="bottom-toolbar">';
		$copyright_text = trim(get_option(THEME_SLUG."_copyright_text"));
		if($copyright_text) {
			echo '<div class="copyright">'.get_option(THEME_SLUG."_copyright_text").'</div>';
		}	
		echo '<a href="#" class="link-top">Top</a>';
		echo '<div class="clear"></div></div>';
		echo '</div>';
	}
}


function theme_formatter($content) {
	$new_content = '';
	$pattern_full = '{(\[raw\].*?\[/raw\])}is';
	$pattern_contents = '{\[raw\](.*?)\[/raw\]}is';
	$pieces = preg_split($pattern_full, $content, -1, PREG_SPLIT_DELIM_CAPTURE);
	
	foreach ($pieces as $piece) {
		if (preg_match($pattern_contents, $piece, $matches)) {
			$new_content .= $matches[1];
		} else {
			$new_content .= wptexturize(wpautop($piece));
		}
	}

	return $new_content;
}
remove_filter ('the_content',  'wpautop');
remove_filter ('comment_text', 'wpautop');
remove_filter('the_content', 'wptexturize');
add_filter('the_content', 'theme_formatter', 99);


function wp_new_excerpt($text) {
	if ($text == '')
	{
		$text = get_the_content('');
		$text = strip_shortcodes( $text );
		$text = apply_filters('the_content', $text);
		$text = str_replace(']]>', ']]>', $text);
		$text = strip_tags($text);
		$text = nl2br($text);
		$excerpt_length = apply_filters('excerpt_length', 80);
		$words = explode(' ', $text, $excerpt_length + 1);
		if (count($words) > $excerpt_length) {
			array_pop($words);
			array_push($words, '...');
			$text = implode(' ', $words);
		}
	}
	return $text;
}
remove_filter('get_the_excerpt', 'wp_trim_excerpt');
add_filter('get_the_excerpt', 'wp_new_excerpt');



add_filter('user_contactmethods','hide_profile_fields',10,1);

function hide_profile_fields( $contactmethods ) {
unset($contactmethods['aim']);
unset($contactmethods['jabber']);
unset($contactmethods['yim']);
return $contactmethods;
}




/* CUSTOM ARCHIVES PARAMETERS 

MODIFIED BY FIVESQUARED, ORIGINAL PLUGIN DEVELOPER:
Plugin Name: Archives for a category 
Plugin URI: http://kwebble.com/blog/2007_08_15/archives_for_a_category
Description: Adds a cat parameter to wp_get_archives() to limit the posts used to generate the archive links to one or more categories.   
Author: Rob Schlüter
Author URI: http://kwebble.com/
Version: 1.4a

Copyright
=========
Copyright 2007, 2008, 2009 Rob Schlüter. All rights reserved.

Licensing terms
===============
- You may use, change and redistribute this software provided the copyright notice above is included. 
- This software is provided without warranty, you use it at your own risk. 
*/
function kwebble_getarchives_where_for_category($where, $args){
	global $kwebble_getarchives_data, $wpdb;

	if (isset($args['cat'])){
		// Preserve the category for later use.
		$kwebble_getarchives_data['cat'] = $args['cat'];

		// Split 'cat' parameter in categories to include and exclude.
		$allCategories = explode(',', $args['cat']);

		// Element 0 = included, 1 = excluded.
		$categories = array(array(), array());
		foreach ($allCategories as $cat) {
			if (strpos($cat, ' ') !== FALSE) {
				// Multi category selection.
			}
			$idx = $cat < 0 ? 1 : 0;
			$categories[$idx][] = abs($cat);
		}

		$includedCatgories = implode(',', $categories[0]);
		$excludedCatgories = implode(',', $categories[1]);

		// Add SQL to perform selection.
		if (get_bloginfo('version') < 2.3){
			$where .= " AND $wpdb->posts.ID IN (SELECT DISTINCT ID FROM $wpdb->posts JOIN $wpdb->post2cat post2cat ON post2cat.post_id=ID";

			if (!empty($includedCatgories)) {
				$where .= " AND post2cat.category_id IN ($includedCatgories)";
			}
			if (!empty($excludedCatgories)) {
				$where .= " AND post2cat.category_id NOT IN ($excludedCatgories)";
			}

			$where .= ')';
		} else{
			$where .= ' AND ' . $wpdb->prefix . 'posts.ID IN (SELECT DISTINCT ID FROM ' . $wpdb->prefix . 'posts'
					. ' JOIN ' . $wpdb->prefix . 'term_relationships term_relationships ON term_relationships.object_id = ' . $wpdb->prefix . 'posts.ID'
					. ' JOIN ' . $wpdb->prefix . 'term_taxonomy term_taxonomy ON term_taxonomy.term_taxonomy_id = term_relationships.term_taxonomy_id'
					. ' WHERE term_taxonomy.taxonomy = \'category\'';
			if (!empty($includedCatgories)) {
				$where .= " AND term_taxonomy.term_id IN ($includedCatgories)";
			}
			if (!empty($excludedCatgories)) {
				$where .= " AND term_taxonomy.term_id NOT IN ($excludedCatgories)";
			}

			$where .= ')';
		}
	}

	return $where;
}

 /* Changes the archive link to include the categories from the 'cat' parameter.
 */
function kwebble_archive_link_for_category($url){
	global $kwebble_getarchives_data;

	if (isset($kwebble_getarchives_data['cat'])){
		$url .= strpos($url, '?') === false ? '?' : '&';
		$url .= 'cat=' . $kwebble_getarchives_data['cat'];

		// Remove cat parameter so it's not automatically used in all following archive lists.
		unset($kwebble_getarchives_data['cat']);
	}

	return $url;
}

// Prevent error if executed outside WordPress.
if (function_exists('add_filter')){
	// Constants for form field and options.
	define('KWEBBLE_OPTION_DISABLE_CANONICAL_URLS', 'kwebble_disable_canonical_urls');
	define('KWEBBLE_GETARCHIVES_FORM_CANONICAL_URLS', 'kwebble_disable_canonical_urls');
	define('KWEBBLE_ENABLED', '');
	define('KWEBBLE_DISABLED', 'Y');

	add_filter('getarchives_where', 'kwebble_getarchives_where_for_category', 10, 2);

	add_filter('year_link', 'kwebble_archive_link_for_category');
	add_filter('month_link', 'kwebble_archive_link_for_category');
	add_filter('day_link', 'kwebble_archive_link_for_category');

	// Disable canonical URLs if the option is set.
	if (get_option(KWEBBLE_OPTION_DISABLE_CANONICAL_URLS) == KWEBBLE_DISABLED){
		remove_filter('template_redirect', 'redirect_canonical');
	}
}

?>